Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ItemInCollection ¶
ItemInCollection checks to see if a string is in an array of strings
func RandomItem ¶
RandomItem returns a random string from an array of strings
func RandomItemFromThresholdMap ¶
RandomItemFromThresholdMap returns a random weighted string
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.